diff cmdline/org/tmatesoft/hg/console/Tags.java @ 367:2fadf8695f8a

Use 'revision index' instead of the vague 'local revision number' concept in the API
author Artem Tikhomirov <tikhomirov.artem@gmail.com>
date Fri, 16 Dec 2011 15:37:27 +0100
parents 45dc79e545f5
children 6437d261048a
line wrap: on
line diff
--- a/cmdline/org/tmatesoft/hg/console/Tags.java	Fri Dec 16 04:43:18 2011 +0100
+++ b/cmdline/org/tmatesoft/hg/console/Tags.java	Fri Dec 16 15:37:27 2011 +0100
@@ -55,7 +55,7 @@
 			}
 		});
 		for (TagInfo ti : tags.getTags().values()) {
-			int x = clog.getLocalRevision(ti.revision()); // XXX in fact, performance hog. Need batch localRevision or another improvement
+			int x = clog.getRevisionIndex(ti.revision()); // XXX in fact, performance hog. Need batch revisionIndex or another improvement
 			ti2index.put(ti, x);
 			sorted.add(ti);
 		}